searchData={"items":[{"type":"module","title":"FritzApi","doc":"A Fritz!Box Home Automation API Client for Elixir.","ref":"FritzApi.html"},{"type":"module","title":"Usage - FritzApi","doc":"iex> {:ok, client} = FritzApi.Client.new()\n    ...>                 |> FritzApi.Client.login(\"admin\", \"changeme\")\n\n    iex> FritzApi.set_switch_off(client, \"687690315761\")\n    :ok\n\n    iex> FritzApi.get_temperature(client, \"687690315761\")\n    {:ok, 23.5}","ref":"FritzApi.html#module-usage"},{"type":"module","title":"Configuration - FritzApi","doc":"The main way to configure FritzApi is through the options passed to `FritzApi.Client.new/1`.\n\nTo customize the behaviour of the HTTP client used by FritzApi, you can configure FritzApi through\nthe application environment . For example, you can do this in `config/runtime.exs`:\n\n    # config/runtime.exs\n    config :fritz_api,\n      # ...\n\nYou can use these options:\n\n- `:client` (`t:module/0`) - A module that implements the `FritzApi.HTTPClient`\nbehaviour. Defaults to `FritzApi.HTTPClient.Finch` (requires `:finch`).\n\n- `:client_pool_opts` (`t:keyword/0`) - Options to configure the HTTP client pool. See\n`Finch.start_link/1`. Defaults to `[]`.\n\n- `:client_request_opts` (`t:keyword/0`) - Options passed to the `c:FritzApi.HTTPClient.get/2`\ncallback. See `Finch.request/3`. Defaults to `[]`.","ref":"FritzApi.html#module-configuration"},{"type":"function","title":"FritzApi.disable_hkr_target_temperature/2","doc":"Disable the target temperature of the radiator controller.","ref":"FritzApi.html#disable_hkr_target_temperature/2"},{"type":"function","title":"Example - FritzApi.disable_hkr_target_temperature/2","doc":"iex> FritzApi.disable_hkr_target_temperature(client, \"687690315761\")\n    {:ok, 23.5}","ref":"FritzApi.html#disable_hkr_target_temperature/2-example"},{"type":"function","title":"FritzApi.enable_hkr_target_temperature/2","doc":"Enabele the target temperature of the radiator controller.","ref":"FritzApi.html#enable_hkr_target_temperature/2"},{"type":"function","title":"Example - FritzApi.enable_hkr_target_temperature/2","doc":"iex> FritzApi.enable_hkr_target_temperature(client, \"687690315761\")\n    {:ok, 23.5}","ref":"FritzApi.html#enable_hkr_target_temperature/2-example"},{"type":"function","title":"FritzApi.get_device_list_infos/1","doc":"Get essential information of all smart home devices.","ref":"FritzApi.html#get_device_list_infos/1"},{"type":"function","title":"Example - FritzApi.get_device_list_infos/1","doc":"iex> FritzApi.get_device_list_infos(client)\n    {:ok, [%FritzApi.Actor{\n       ain: \"687690315761\",\n       alert: nil,\n       functions: [\"Energie Messgerät\", \"Temperatursensor\",\n         \"Schaltsteckdose\", \"Mikrofon\"],\n       fwversion: \"04.17\",\n       id: \"1\",\n       manufacturer: \"AVM\",\n       name: \"Aussensteckdose\",\n       powermeter: %FritzApi.Powermeter{\n         energy: 8.94,\n         power: 0.0,\n         voltage: 231.17\n       },\n       present: true,\n       productname: \"FRITZ!DECT 210\",\n       switch: %FritzApi.Switch{\n         devicelock: false,\n         lock: false,\n         mode: :auto,\n         state: false\n       },\n       temperature: %FritzApi.Temperature{\n         celsius: 21.0,\n         offset: 0.0\n       }\n     }]}","ref":"FritzApi.html#get_device_list_infos/1-example"},{"type":"function","title":"FritzApi.get_hkr_comfort_temperature/2","doc":"Get the comfort temperature (Celsius) set for time switching of the radiator\ncontroller.","ref":"FritzApi.html#get_hkr_comfort_temperature/2"},{"type":"function","title":"Example - FritzApi.get_hkr_comfort_temperature/2","doc":"iex> FritzApi.get_hkr_comfort_temperature(client, \"687690315761\")\n    {:ok, 23.5}","ref":"FritzApi.html#get_hkr_comfort_temperature/2-example"},{"type":"function","title":"FritzApi.get_hkr_economy_temperature/2","doc":"Get the economy temperature (Celsius) set for time switching of the radiator\ncontroller.","ref":"FritzApi.html#get_hkr_economy_temperature/2"},{"type":"function","title":"Example - FritzApi.get_hkr_economy_temperature/2","doc":"iex> FritzApi.get_hkr_economy_temperature(client, \"687690315761\")\n    {:ok, 23.5}","ref":"FritzApi.html#get_hkr_economy_temperature/2-example"},{"type":"function","title":"FritzApi.get_hkr_target_temperature/2","doc":"Get the target temperature (Celsius) currently set for the radiator\ncontroller.","ref":"FritzApi.html#get_hkr_target_temperature/2"},{"type":"function","title":"Example - FritzApi.get_hkr_target_temperature/2","doc":"iex> FritzApi.get_hkr_target_temperature(client, \"687690315761\")\n    {:ok, 23.5}","ref":"FritzApi.html#get_hkr_target_temperature/2-example"},{"type":"function","title":"FritzApi.get_switch_energy/2","doc":"Get the total energy usage (kWh) of the switch.\n\nReturns `{:ok, :unknown}` if the state is unknown.","ref":"FritzApi.html#get_switch_energy/2"},{"type":"function","title":"Example - FritzApi.get_switch_energy/2","doc":"iex> FritzApi.get_switch_energy(client, \"687690315761\")\n    {:ok, 0.475}","ref":"FritzApi.html#get_switch_energy/2-example"},{"type":"function","title":"FritzApi.get_switch_list/1","doc":"Get the actuator identification numbers (AIN) of all known actors.","ref":"FritzApi.html#get_switch_list/1"},{"type":"function","title":"Example - FritzApi.get_switch_list/1","doc":"iex> FritzApi.get_switch_list(client)\n    {:ok, [\"687690315761\"]}","ref":"FritzApi.html#get_switch_list/1-example"},{"type":"function","title":"FritzApi.get_switch_name/2","doc":"Get the name of the actor.","ref":"FritzApi.html#get_switch_name/2"},{"type":"function","title":"Example - FritzApi.get_switch_name/2","doc":"iex> FritzApi.get_switch_name(client, \"687690315761\")\n    {:ok, \"FRITZ!DECT #1\"}","ref":"FritzApi.html#get_switch_name/2-example"},{"type":"function","title":"FritzApi.get_switch_power/2","doc":"Get the current power consumption (Watt) of the switch.\n\nReturns `{:ok, :unknown}` if the state is unknown.","ref":"FritzApi.html#get_switch_power/2"},{"type":"function","title":"Example - FritzApi.get_switch_power/2","doc":"iex> FritzApi.get_switch_power(client, \"687690315761\")\n    {:ok, 0.0}","ref":"FritzApi.html#get_switch_power/2-example"},{"type":"function","title":"FritzApi.get_switch_present/2","doc":"Get the current connection state of the actor.","ref":"FritzApi.html#get_switch_present/2"},{"type":"function","title":"Example - FritzApi.get_switch_present/2","doc":"iex> FritzApi.get_switch_present(client, \"687690315761\")\n    {:ok, true}","ref":"FritzApi.html#get_switch_present/2-example"},{"type":"function","title":"FritzApi.get_switch_state/2","doc":"Get the current switching state.\n\nReturns `{:ok, :unknown}` if the state is unknown.","ref":"FritzApi.html#get_switch_state/2"},{"type":"function","title":"Example - FritzApi.get_switch_state/2","doc":"iex> FritzApi.get_switch_state(client, \"687690315761\")\n    {:ok, :on}","ref":"FritzApi.html#get_switch_state/2-example"},{"type":"function","title":"FritzApi.get_temperature/2","doc":"Get the last measured temperature (Celsius) of the actor.\n\nReturns `{:ok, :unknown}` if the temperature could not be measured.","ref":"FritzApi.html#get_temperature/2"},{"type":"function","title":"Example - FritzApi.get_temperature/2","doc":"iex> FritzApi.get_temperature(client, \"687690315761\")\n    {:ok, 23.5}","ref":"FritzApi.html#get_temperature/2-example"},{"type":"function","title":"FritzApi.set_hkr_target_temperature/3","doc":"Set the target temperature (Celsius) of the radiator controller.","ref":"FritzApi.html#set_hkr_target_temperature/3"},{"type":"function","title":"Example - FritzApi.set_hkr_target_temperature/3","doc":"iex> FritzApi.set_hkr_target_temperature(client, \"687690315761\", 21.5)\n    {:ok, 23.5}","ref":"FritzApi.html#set_hkr_target_temperature/3-example"},{"type":"function","title":"FritzApi.set_switch_off/2","doc":"Turn off the switch.","ref":"FritzApi.html#set_switch_off/2"},{"type":"function","title":"Example - FritzApi.set_switch_off/2","doc":"iex> FritzApi.set_switch_off(client, \"687690315761\")\n    :ok","ref":"FritzApi.html#set_switch_off/2-example"},{"type":"function","title":"FritzApi.set_switch_on/2","doc":"Turn on the switch.","ref":"FritzApi.html#set_switch_on/2"},{"type":"function","title":"Example - FritzApi.set_switch_on/2","doc":"iex> FritzApi.set_switch_on(client, \"687690315761\")\n    :ok","ref":"FritzApi.html#set_switch_on/2-example"},{"type":"function","title":"FritzApi.set_switch_toggle/2","doc":"Toggle the switch.","ref":"FritzApi.html#set_switch_toggle/2"},{"type":"function","title":"Example - FritzApi.set_switch_toggle/2","doc":"iex> FritzApi.set_switch_toggle(client, \"687690315761\")\n    {:ok, :off}","ref":"FritzApi.html#set_switch_toggle/2-example"},{"type":"type","title":"FritzApi.ain/0","doc":"Unique actor identifier.","ref":"FritzApi.html#t:ain/0"},{"type":"type","title":"FritzApi.password/0","doc":"Password of the FritzBox user.","ref":"FritzApi.html#t:password/0"},{"type":"type","title":"FritzApi.useranme/0","doc":"Name of the FritzBox user.\n\n> ##","ref":"FritzApi.html#t:useranme/0"},{"type":"type","title":"Note {: .info} - FritzApi.useranme/0","doc":">\n> With FRITZ! OS 7.24 and later, the user name cannot be empty.","ref":"FritzApi.html#t:useranme/0-note-info"},{"type":"module","title":"FritzApi.Client","doc":"A FritzApi API Client","ref":"FritzApi.Client.html"},{"type":"function","title":"FritzApi.Client.login/3","doc":"Authenticate with the FritzApi API using the name and password of the user.\n\nA valid session ID is required in order to interact with the FritzBox API.\n\nEach application should only acquire a single session ID since the number of\nsessions to a FritzBox is limited.\n\nIn principle, each session ID has a validity of 60 Minutes whereby the\nvalidity period gets extended with every access to the API. However, if any\napplication tries to access the API with an invalid session ID, all other\nsessions get terminated.","ref":"FritzApi.Client.html#login/3"},{"type":"function","title":"Examples - FritzApi.Client.login/3","doc":"iex> {:ok, client} = FritzApi.Client.new()\n    ...>                 |> FritzApi.Client.login(username, password)\n    {:ok, %FritzApi.Client{}}","ref":"FritzApi.Client.html#login/3-examples"},{"type":"function","title":"FritzApi.Client.new/1","doc":"Creates a new FritzApi API client.","ref":"FritzApi.Client.html#new/1"},{"type":"function","title":"Options - FritzApi.Client.new/1","doc":"* `:base_url` - the base URL for all endpoints (default: `http://fritz.box`)","ref":"FritzApi.Client.html#new/1-options"},{"type":"function","title":"Examples - FritzApi.Client.new/1","doc":"iex> client = FritzApi.Client.new()\n    %FritzApi.Client{}","ref":"FritzApi.Client.html#new/1-examples"},{"type":"opaque","title":"FritzApi.Client.t/0","doc":"","ref":"FritzApi.Client.html#t:t/0"},{"type":"behaviour","title":"FritzApi.HTTPClient","doc":"Specifies the API for using a custom HTTP Client.\n\nThe default HTTP client is `FritzApi.HTTPClient.Finch`.\n\nTo configure a different HTTP client, implement the `FritzApi.HTTPClient` behaviour\nand change the `:client` configuration:\n\n    config :fritz_api, :client, MyHTTPClient","ref":"FritzApi.HTTPClient.html"},{"type":"behaviour","title":"Example - FritzApi.HTTPClient","doc":"A client implementation based on `:hackney` could look like this:\n\n    defmodule MyHTTPClient do\n      @behaviour LoggerTelegramBackend.HTTPClient\n\n      @hackney_pool_name :logger_telegram_backend_pool\n\n      @impl true\n      def child_spec(opts) do\n        :hackney_pool.child_spec(@hackney_pool_name, opts)\n      end\n\n      @impl true\n      def request(method, url, headers, body, opts) do\n        opts = Keyword.merge(opts, pool: @hackney_pool_name) ++ [:with_body]\n\n        case :hackney.request(method, url, headers, body, opts) do\n          {:ok, _status, _headers, _body} = result -> result\n          {:error, _reason} = error -> error\n        end\n      end\n    end","ref":"FritzApi.HTTPClient.html#module-example"},{"type":"callback","title":"FritzApi.HTTPClient.child_spec/1","doc":"Should return a **child specification** to start the HTTP client or `nil`.\n\nFor example, this can start a pool of HTTP connections dedicated to FritzApi.","ref":"FritzApi.HTTPClient.html#c:child_spec/1"},{"type":"callback","title":"FritzApi.HTTPClient.get/2","doc":"Should make an HTTP request to `t:url/0` with the given `t:req_opts/0`.","ref":"FritzApi.HTTPClient.html#c:get/2"},{"type":"type","title":"FritzApi.HTTPClient.body/0","doc":"HTTP request or response body.","ref":"FritzApi.HTTPClient.html#t:body/0"},{"type":"type","title":"FritzApi.HTTPClient.headers/0","doc":"HTTP request or response headers.","ref":"FritzApi.HTTPClient.html#t:headers/0"},{"type":"type","title":"FritzApi.HTTPClient.method/0","doc":"HTTP request method.","ref":"FritzApi.HTTPClient.html#t:method/0"},{"type":"type","title":"FritzApi.HTTPClient.params/0","doc":"HTTP request query params.","ref":"FritzApi.HTTPClient.html#t:params/0"},{"type":"type","title":"FritzApi.HTTPClient.pool_opts/0","doc":"Options to configure the pool (set via `:client_pool_opts`).","ref":"FritzApi.HTTPClient.html#t:pool_opts/0"},{"type":"type","title":"FritzApi.HTTPClient.req_opts/0","doc":"HTTP request options (set via `:client_request_opts`).","ref":"FritzApi.HTTPClient.html#t:req_opts/0"},{"type":"type","title":"FritzApi.HTTPClient.status/0","doc":"HTTP response status.","ref":"FritzApi.HTTPClient.html#t:status/0"},{"type":"type","title":"FritzApi.HTTPClient.url/0","doc":"HTTP request URL.","ref":"FritzApi.HTTPClient.html#t:url/0"},{"type":"module","title":"FritzApi.HTTPClient.Finch","doc":"The built-in HTTP client, based on [finch](https://github.com/sneako/finch).\n\nIt client implements the `FritzApi.HTTPClient` behaviour.\n\nSee `FritzApi` for the available configuration options and `FritzApi.HTTPClient` if you wish to\nuse another HTTP client.","ref":"FritzApi.HTTPClient.Finch.html"},{"type":"module","title":"FritzApi.Actor","doc":"A smart home actor.\n\n#","ref":"FritzApi.Actor.html"},{"type":"module","title":"Properties: - FritzApi.Actor","doc":"- `ain`: identification of the actor, e.g. \"012340000123\" or MAC address for\nnetwork devices\n- `fwversion`: firmware version of the device\n- `id`: internal device ID\n- `manufacturer`: should always be \"AVM\"\n- `productname`: product name of the device; `nil` if undefined or unknown\n- `present`: indicates whether the devices is connected with the FritzBox;\neither `true`, `false` or `nil`\n- `name`: name of the device\n- `functions`: list of device function classes","ref":"FritzApi.Actor.html#module-properties"},{"type":"type","title":"FritzApi.Actor.t/0","doc":"","ref":"FritzApi.Actor.html#t:t/0"},{"type":"module","title":"FritzApi.Alert","doc":"An alert sensor\n\n#","ref":"FritzApi.Alert.html"},{"type":"module","title":"Properties - FritzApi.Alert","doc":"- `state`: last known alert state; either `true`, `false` or `nil`\n- `last_alert_change`: time of the last alert change","ref":"FritzApi.Alert.html#module-properties"},{"type":"type","title":"FritzApi.Alert.t/0","doc":"","ref":"FritzApi.Alert.html#t:t/0"},{"type":"module","title":"FritzApi.Powermeter","doc":"A power meter\n\n#","ref":"FritzApi.Powermeter.html"},{"type":"module","title":"Properties - FritzApi.Powermeter","doc":"- `power`: current power consumption (Watts); gets updated roughly every 2\nminutes\n- `energy`: total energy usage (kWh) since first use\n- `voltage`: crurent voltage (V); gets updated roughly every 2 minutes","ref":"FritzApi.Powermeter.html#module-properties"},{"type":"type","title":"FritzApi.Powermeter.t/0","doc":"","ref":"FritzApi.Powermeter.html#t:t/0"},{"type":"module","title":"FritzApi.Switch","doc":"A Switch\n\n#","ref":"FritzApi.Switch.html"},{"type":"module","title":"Properties - FritzApi.Switch","doc":"- `state`: switching state; either `true`, `false` or `nil`\n- `mode`: `:auto` if in timer switch mode, otherwise `:manual`; can also be\n`nil` if undefined / unknown\n- `lock`: state of the shift lock (via UI/API); either `true`, `false` or `nil`\n- `devicelock`: state of the shift lock (via hardware button); either `true`,\n`false` or `nil`","ref":"FritzApi.Switch.html#module-properties"},{"type":"type","title":"FritzApi.Switch.t/0","doc":"","ref":"FritzApi.Switch.html#t:t/0"},{"type":"module","title":"FritzApi.Temperature","doc":"A temperature sensor\n\n#","ref":"FritzApi.Temperature.html"},{"type":"module","title":"Properties: - FritzApi.Temperature","doc":"- `celsius`: last measured temperature\n- `offsset`: configured offsset value","ref":"FritzApi.Temperature.html#module-properties"},{"type":"type","title":"FritzApi.Temperature.t/0","doc":"","ref":"FritzApi.Temperature.html#t:t/0"},{"type":"exception","title":"FritzApi.Error","doc":"A FritzApi Error","ref":"FritzApi.Error.html"},{"type":"type","title":"FritzApi.Error.response/0","doc":"","ref":"FritzApi.Error.html#t:response/0"},{"type":"type","title":"FritzApi.Error.t/0","doc":"","ref":"FritzApi.Error.html#t:t/0"},{"type":"extras","title":"FritzApi","doc":"# FritzApi\n\n[![Build Status](https://github.com/adriankumpf/fritz-api/workflows/CI/badge.svg)](https://github.com/adriankumpf/fritz-api/actions)\n[![Docs](https://img.shields.io/badge/hex-docs-green.svg?style=flat)](https://hexdocs.pm/fritz_api)\n[![Hex.pm](https://img.shields.io/hexpm/v/fritz_api?color=%23714a94)](http://hex.pm/packages/fritz_api)\n\n \n\nFritz!Box Home Automation API Client for Elixir\n([documentation](https://hexdocs.pm/fritz_api)).","ref":"readme.html"},{"type":"extras","title":"Installation - FritzApi","doc":"Add `:fritz_api` and `:finch` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:fritz_api, \"~> 3.0\"},\n    {:finch, \"~> 0.16\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - FritzApi","doc":"```elixir\niex> {:ok, client} = FritzApi.Client.new()\n...>                 |> FritzApi.Client.login(\"admin\", \"changeme\")\n\niex> FritzApi.get_device_list_infos(client)\n{:ok, [%FritzApi.Actor{\n  ain: \"687690315761\",\n  fwversion: \"03.87\",\n  id: 21,\n  manufacturer: \"AVM\",\n  name: \"FRITZ!DECT #1\",\n  powermeter: %{energy: 0.475, power: 0.0},\n  present: true,\n  productname: \"FRITZ!DECT 200\",\n  switch: %{\n    devicelock: false,\n    lock: false,\n    mode: :manual,\n    state: false\n  },\n  temperature: %{\n    celsius: 23.5,\n    offset: 0.0\n  }\n}]}\n\niex> FritzApi.set_switch_off(client, \"687690315761\")\n:ok\n\niex> FritzApi.get_temperature(client, \"687690315761\")\n{:ok, 23.5}\n```","ref":"readme.html#usage"},{"type":"extras","title":"References - FritzApi","doc":"- [AHA HTTP Interface](https://avm.de/fileadmin/user_upload/Global/Service/Schnittstellen/AHA-HTTP-Interface.pdf)\n- [AVM Technical Note - Session ID](https://avm.de/fileadmin/user_upload/Global/Service/Schnittstellen/AVM_Technical_Note_-_Session_ID.pdf)","ref":"readme.html#references"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"3.0.0 (2023-08-12) - Changelog","doc":"#","ref":"changelog.html#3-0-0-2023-08-12"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Migrate built-in HTTP from `hackney` to `Finch`\n- Replace the`:adapter` with the `:client` option\n\n#","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Upgrade instructions - Changelog","doc":"##","ref":"changelog.html#upgrade-instructions"},{"type":"extras","title":"Dependencies - Changelog","doc":"FritzApi now ships with an HTTP client based on `:finch` instead of `:hackney`.\n\nAdd `:finch` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:fritz_api, \"~> 3.0\"},\n    {:finch, \"~> 0.16\"},\n  ]\nend\n```\n\n##","ref":"changelog.html#dependencies"},{"type":"extras","title":"HTTP client (optional) - Changelog","doc":"1. Remove the `:adapter` configuration from `FritzApi.Client.new/1`:\n\n   ```diff\n   {:ok, client} = FritzApi.Client.new(\n   -  adapter: {Tesla.Adapter.Gun, []}\n   )\n   ```\n\n2. In `config/runtime.exs` set the `:fritz_api, :client` option and to your own module that implements the `FritzApi.HTTPClient` behaviour:\n\n   ```diff\n   + config :fritz_api,\n   +   client: MyGunAdapter\n   ```\n\nSee the documentation for `FritzApi.HTTPClient` for more information.","ref":"changelog.html#http-client-optional"},{"type":"extras","title":"2.2.0 (2022-12-29) - Changelog","doc":"- Fix deprecation warning\n- Update dependencies","ref":"changelog.html#2-2-0-2022-12-29"},{"type":"extras","title":"2.1.0 (2022-02-22) - Changelog","doc":"- Bump elixir_xml_to_map to 3.0","ref":"changelog.html#2-1-0-2022-02-22"},{"type":"extras","title":"2.0.0 (2020-11-27) - Changelog","doc":"FritzApi 2.0 is a major release containing significant changes, particularly around the `FritzApi.Client`.\n\n#","ref":"changelog.html#2-0-0-2020-11-27"},{"type":"extras","title":"Enhancements - Changelog","doc":"- Use [tesla](https://github.com/teamon/tesla) to make the underlying HTTP client configurable\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Replace the stateful `FritzApi.Client` that would need to be started as part of a supervision tree with a simpler struct based approach:\n  - Call `FritzApi.Client.new()` to create a new client and `FritzApi.Client.login(client, \"user\", \"password\")` to authenticate with the Fritz API\n  - See README for an example\n- Switch functions like `FritzApi.get_switch_state/2` return `:on`, `:off` atoms instead of a boolean, and `:unknown` if the actor is unavailable\n- Introduce a custom error struct (`FritzApi.Error`) and use custom structs for actors (e.g. `FritzApi.Switch`)\n- Make hackney an optional dependency. To use the default `hackney` based adapter, add `{:hackney, \"~> 1.16\"}` to the list of dependencies.","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Automatic session refresh","doc":"# Automatic session refresh\n\nAt some point every FritzBox session expires. This will result in `{:error, %FritzApi.Error{reason: :session_expired}}` errors.\n\nTo refresh a session, call `FritzApi.Client.login/3` again.","ref":"automatic_session_refresh.html"},{"type":"extras","title":"Example - Automatic session refresh","doc":"```elixir\ndefmodule Switch do\n  use GenServer\n\n  defmodule State do\n    @derive {Inspect, except: [:password]}\n    defstruct [:username, :password, :ain, :client]\n  end\n\n  def start_link(opts), do: GenServer.start_link(__MODULE__, opts)\n  def toggle, do: GenServer.call(__MODULE__, :toggle)\n\n  @impl true\n  def init(opts) do\n\n    state = %State{\n      client: FritzApi.Client.new(),\n      username: Keyword.fetch!(opts, :username),\n      password: Keyword.fetch!(opts, :password),\n      ain: Keyword.fetch!(opts, :ain)\n    }\n\n    {:ok, state, {:continue, :login}}\n  end\n\n  @impl true\n  def handle_continue(:login, %State{} = state) do\n    {:ok, client} = FritzApi.Client.login(state.client, state.username, state.password)\n    {:noreply, put_in(state.client, client)}\n  end\n\n  @impl true\n  def handle_call(:toggle, _from, %State{} = state) do\n    {result, state} = refresh_session(&FritzApi.set_switch_toggle(&1, state.ain), state)\n    {:reply, result, state}\n  end\n\n  defp refresh_session(fun, %State{} = state) do\n    with {:error, %FritzApi.Error{reason: :session_expired}}   {result, state}\n    end\n  end\nend\n```\n\n```elixir\niex> {:ok, pid} = Switch.start_link(username: \"admin\", password: \"admin\", ain: \"000111222333\")\niex> Switch.toggle(pid)\n:ok\n```","ref":"automatic_session_refresh.html#example"}],"content_type":"text/markdown"}